var threeOBJ = require("../index")(),
	fs = require("fs");

//threeOBJ.set({ align: "bottom" });

threeOBJ.minify("./import/mesh.obj", "./export/mesh.js", function( response ){
	console.log( "File saved at: binary/palm.js"  );
});
